Current rte_flow_action_modify_data struct describes the pkt
field perfectly and is used only in action.

It is planned to be used for item as well. This commit renames
it to "rte_flow_field_data" making it compatible to be used by item.

Signed-off-by: Suanming Mou <suanmi...@nvidia.com>
Acked-by: Ori Kam <or...@nvidia.com>
Acked-by: Andrew Rybchenko <andrew.rybche...@oktetlabs.ru>
---
 app/test-pmd/cmdline_flow.c            | 22 +++++++++++-----------
 doc/guides/prog_guide/rte_flow.rst     |  2 +-
 doc/guides/rel_notes/release_24_03.rst |  1 +
 drivers/net/mlx5/mlx5_flow.c           |  4 ++--
 drivers/net/mlx5/mlx5_flow.h           |  8 ++++----
 drivers/net/mlx5/mlx5_flow_dv.c        | 12 ++++++------
 drivers/net/mlx5/mlx5_flow_geneve.c    |  2 +-
 lib/ethdev/rte_flow.h                  |  8 ++++----
 8 files changed, 30 insertions(+), 29 deletions(-)

diff --git a/app/test-pmd/cmdline_flow.c b/app/test-pmd/cmdline_flow.c
index 4062879552..4741ec679d 100644
--- a/app/test-pmd/cmdline_flow.c
+++ b/app/test-pmd/cmdline_flow.c
@@ -745,13 +745,13 @@ enum index {
 #define ITEM_RAW_SIZE \
        (sizeof(struct rte_flow_item_raw) + ITEM_RAW_PATTERN_SIZE)
 
-/** Maximum size for external pattern in struct rte_flow_action_modify_data. */
-#define ACTION_MODIFY_PATTERN_SIZE 32
+/** Maximum size for external pattern in struct rte_flow_field_data. */
+#define FLOW_FIELD_PATTERN_SIZE 32
 
 /** Storage size for struct rte_flow_action_modify_field including pattern. */
 #define ACTION_MODIFY_SIZE \
        (sizeof(struct rte_flow_action_modify_field) + \
-       ACTION_MODIFY_PATTERN_SIZE)
+       FLOW_FIELD_PATTERN_SIZE)
 
 /** Maximum number of queue indices in struct rte_flow_action_rss. */
 #define ACTION_RSS_QUEUE_NUM 128
@@ -945,7 +945,7 @@ static const char *const modify_field_ops[] = {
        "set", "add", "sub", NULL
 };
 
-static const char *const modify_field_ids[] = {
+static const char *const flow_field_ids[] = {
        "start", "mac_dst", "mac_src",
        "vlan_type", "vlan_id", "mac_type",
        "ipv4_dscp", "ipv4_ttl", "ipv4_src", "ipv4_dst",
@@ -7016,7 +7016,7 @@ static const struct token token_list[] = {
                             ARGS_ENTRY_ARB(0, 0),
                             ARGS_ENTRY_ARB
                                (sizeof(struct rte_flow_action_modify_field),
-                                ACTION_MODIFY_PATTERN_SIZE)),
+                                FLOW_FIELD_PATTERN_SIZE)),
                .call = parse_vc_conf,
        },
        [ACTION_MODIFY_FIELD_WIDTH] = {
@@ -9828,10 +9828,10 @@ parse_vc_modify_field_id(struct context *ctx, const 
struct token *token,
        if (ctx->curr != ACTION_MODIFY_FIELD_DST_TYPE_VALUE &&
                ctx->curr != ACTION_MODIFY_FIELD_SRC_TYPE_VALUE)
                return -1;
-       for (i = 0; modify_field_ids[i]; ++i)
-               if (!strcmp_partial(modify_field_ids[i], str, len))
+       for (i = 0; flow_field_ids[i]; ++i)
+               if (!strcmp_partial(flow_field_ids[i], str, len))
                        break;
-       if (!modify_field_ids[i])
+       if (!flow_field_ids[i])
                return -1;
        if (!ctx->object)
                return len;
@@ -12058,10 +12058,10 @@ comp_set_modify_field_id(struct context *ctx, const 
struct token *token,
 
        RTE_SET_USED(token);
        if (!buf)
-               return RTE_DIM(modify_field_ids);
-       if (ent >= RTE_DIM(modify_field_ids) - 1)
+               return RTE_DIM(flow_field_ids);
+       if (ent >= RTE_DIM(flow_field_ids) - 1)
                return -1;
-       name = modify_field_ids[ent];
+       name = flow_field_ids[ent];
        if (ctx->curr == ACTION_MODIFY_FIELD_SRC_TYPE ||
            (strcmp(name, "pointer") && strcmp(name, "value")))
                return strlcpy(buf, name, size);
diff --git a/doc/guides/prog_guide/rte_flow.rst 
b/doc/guides/prog_guide/rte_flow.rst
index 900fdaefb6..f936a9ba19 100644
--- a/doc/guides/prog_guide/rte_flow.rst
+++ b/doc/guides/prog_guide/rte_flow.rst
@@ -3185,7 +3185,7 @@ destination offset as ``48``, and provide immediate value 
``0xXXXX85XX``.
    | ``width``     | number of bits to use   |
    +---------------+-------------------------+
 
-.. _table_rte_flow_action_modify_data:
+.. _table_rte_flow_field_data:
 
 .. table:: destination/source field definition
 
diff --git a/doc/guides/rel_notes/release_24_03.rst 
b/doc/guides/rel_notes/release_24_03.rst
index 2b91217943..b676683b42 100644
--- a/doc/guides/rel_notes/release_24_03.rst
+++ b/doc/guides/rel_notes/release_24_03.rst
@@ -140,6 +140,7 @@ ABI Changes
 
 * No ABI change that would break compatibility with 23.11.
 
+* ethdev: Rename the experimental ``struct rte_flow_action_modify_data`` to be 
``struct rte_flow_field_data``
 
 Known Issues
 ------------
diff --git a/drivers/net/mlx5/mlx5_flow.h b/drivers/net/mlx5/mlx5_flow.h
index c9cc942d80..3f0699e986 100644
--- a/drivers/net/mlx5/mlx5_flow.h
+++ b/drivers/net/mlx5/mlx5_flow.h
@@ -1127,7 +1127,7 @@ flow_items_to_tunnel(const struct rte_flow_item items[])
  *   Tag array index.
  */
 static inline uint8_t
-flow_tag_index_get(const struct rte_flow_action_modify_data *data)
+flow_tag_index_get(const struct rte_flow_field_data *data)
 {
        return data->tag_index ? data->tag_index : data->level;
 }
@@ -1839,7 +1839,7 @@ int mlx5_flow_geneve_tlv_option_validate(struct mlx5_priv 
*priv,
                                         const struct rte_flow_item *geneve_opt,
                                         struct rte_flow_error *error);
 int mlx5_geneve_opt_modi_field_get(struct mlx5_priv *priv,
-                                  const struct rte_flow_action_modify_data 
*data);
+                                  const struct rte_flow_field_data *data);
 
 struct mlx5_geneve_tlv_options_mng;
 int mlx5_geneve_tlv_option_register(struct mlx5_priv *priv,
@@ -2612,7 +2612,7 @@ int mlx5_flow_validate_action_default_miss(uint64_t 
action_flags,
                                const struct rte_flow_attr *attr,
                                struct rte_flow_error *error);
 int flow_validate_modify_field_level
-                       (const struct rte_flow_action_modify_data *data,
+                       (const struct rte_flow_field_data *data,
                         struct rte_flow_error *error);
 int mlx5_flow_item_acceptable(const struct rte_flow_item *item,
                              const uint8_t *mask,
@@ -2919,7 +2919,7 @@ size_t flow_dv_get_item_hdr_len(const enum 
rte_flow_item_type item_type);
 int flow_dv_convert_encap_data(const struct rte_flow_item *items, uint8_t *buf,
                           size_t *size, struct rte_flow_error *error);
 void mlx5_flow_field_id_to_modify_info
-               (const struct rte_flow_action_modify_data *data,
+               (const struct rte_flow_field_data *data,
                 struct field_modify_info *info, uint32_t *mask,
                 uint32_t width, struct rte_eth_dev *dev,
                 const struct rte_flow_attr *attr, struct rte_flow_error 
*error);
diff --git a/drivers/net/mlx5/mlx5_flow_dv.c b/drivers/net/mlx5/mlx5_flow_dv.c
index 6998be107f..a4ed7b1444 100644
--- a/drivers/net/mlx5/mlx5_flow_dv.c
+++ b/drivers/net/mlx5/mlx5_flow_dv.c
@@ -1460,14 +1460,14 @@ flow_modify_info_mask_32_masked(uint32_t length, 
uint32_t off, uint32_t post_mas
 }
 
 static __rte_always_inline enum mlx5_modification_field
-mlx5_mpls_modi_field_get(const struct rte_flow_action_modify_data *data)
+mlx5_mpls_modi_field_get(const struct rte_flow_field_data *data)
 {
        return MLX5_MODI_IN_MPLS_LABEL_0 + data->tag_index;
 }
 
 static __rte_always_inline int
 flow_geneve_opt_modi_field_get(struct mlx5_priv *priv,
-                              const struct rte_flow_action_modify_data *data)
+                              const struct rte_flow_field_data *data)
 {
 #ifdef HAVE_MLX5_HWS_SUPPORT
        return mlx5_geneve_opt_modi_field_get(priv, data);
@@ -1483,7 +1483,7 @@ flow_geneve_opt_modi_field_get(struct mlx5_priv *priv,
 static void
 mlx5_modify_flex_item(const struct rte_eth_dev *dev,
                      const struct mlx5_flex_item *flex,
-                     const struct rte_flow_action_modify_data *data,
+                     const struct rte_flow_field_data *data,
                      struct field_modify_info *info,
                      uint32_t *mask, uint32_t width)
 {
@@ -1613,7 +1613,7 @@ mlx5_dv_modify_ipv6_traffic_class_supported(struct 
mlx5_priv *priv)
 
 void
 mlx5_flow_field_id_to_modify_info
-               (const struct rte_flow_action_modify_data *data,
+               (const struct rte_flow_field_data *data,
                 struct field_modify_info *info, uint32_t *mask,
                 uint32_t width, struct rte_eth_dev *dev,
                 const struct rte_flow_attr *attr, struct rte_flow_error *error)
@@ -5441,8 +5441,8 @@ flow_dv_validate_action_modify_field(struct rte_eth_dev 
*dev,
        struct mlx5_sh_config *config = &priv->sh->config;
        struct mlx5_hca_attr *hca_attr = &priv->sh->cdev->config.hca_attr;
        const struct rte_flow_action_modify_field *conf = action->conf;
-       const struct rte_flow_action_modify_data *src_data = &conf->src;
-       const struct rte_flow_action_modify_data *dst_data = &conf->dst;
+       const struct rte_flow_field_data *src_data = &conf->src;
+       const struct rte_flow_field_data *dst_data = &conf->dst;
        uint32_t dst_width, src_width, width = conf->width;
 
        ret = flow_dv_validate_action_modify_hdr(action_flags, action, error);
diff --git a/drivers/net/mlx5/mlx5_flow_geneve.c 
b/drivers/net/mlx5/mlx5_flow_geneve.c
index d5847a60e9..d8086d333f 100644
--- a/drivers/net/mlx5/mlx5_flow_geneve.c
+++ b/drivers/net/mlx5/mlx5_flow_geneve.c
@@ -326,7 +326,7 @@ mlx5_get_geneve_option_modify_field_id(const void *dr_ctx, 
uint8_t type,
  */
 int
 mlx5_geneve_opt_modi_field_get(struct mlx5_priv *priv,
-                              const struct rte_flow_action_modify_data *data)
+                              const struct rte_flow_field_data *data)
 {
        uint16_t class = data->class_id;
        uint8_t type = data->type;
diff --git a/lib/ethdev/rte_flow.h b/lib/ethdev/rte_flow.h
index 1267c146e5..d9965043e7 100644
--- a/lib/ethdev/rte_flow.h
+++ b/lib/ethdev/rte_flow.h
@@ -3940,9 +3940,9 @@ enum rte_flow_field_id {
  * @warning
  * @b EXPERIMENTAL: this structure may change without prior notice
  *
- * Field description for MODIFY_FIELD action.
+ * Field description for packet field.
  */
-struct rte_flow_action_modify_data {
+struct rte_flow_field_data {
        enum rte_flow_field_id field; /**< Field or memory type ID. */
        union {
                struct {
@@ -4051,8 +4051,8 @@ enum rte_flow_modify_op {
  */
 struct rte_flow_action_modify_field {
        enum rte_flow_modify_op operation; /**< Operation to perform. */
-       struct rte_flow_action_modify_data dst; /**< Destination field. */
-       struct rte_flow_action_modify_data src; /**< Source field. */
+       struct rte_flow_field_data dst; /**< Destination field. */
+       struct rte_flow_field_data src; /**< Source field. */
        uint32_t width; /**< Number of bits to use from a source field. */
 };
 
diff --git a/drivers/net/mlx5/mlx5_flow.c b/drivers/net/mlx5/mlx5_flow.c
index 5159e8e773..40376c99ba 100644
--- a/drivers/net/mlx5/mlx5_flow.c
+++ b/drivers/net/mlx5/mlx5_flow.c
@@ -2493,7 +2493,7 @@ mlx5_validate_action_ct(struct rte_eth_dev *dev,
  * Validate the level value for modify field action.
  *
  * @param[in] data
  *   Pointer to the rte_flow_action_modify_data structure either src or dst.
  * @param[out] error
  *   Pointer to error structure.
  *
@@ -2501,7 +2501,7 @@ mlx5_validate_action_ct(struct rte_eth_dev *dev,
  *   0 on success, a negative errno value otherwise and rte_errno is set.
  */
 int
-flow_validate_modify_field_level(const struct rte_flow_action_modify_data 
*data,
+flow_validate_modify_field_level(const struct rte_flow_field_data *data,
                                 struct rte_flow_error *error)
 {
        if (data->level == 0)
@@ -2493,7 +2493,7 @@ mlx5_validate_action_ct(struct rte_eth_dev *dev,
  *
  * @param[in] data
- *   Pointer to the rte_flow_action_modify_data structure either src or dst.
+ *   Pointer to the rte_flow_field_data structure either src or dst.
  * @param[out] error
  *   Pointer to error structure.
-- 
2.34.1

Reply via email to